@@ -40,13 +40,13 @@ public:
     qint64 startTime = -1;
     qint64 endTime = -1;
     QAbstractVideoBuffer::MapData mapData;
+    QVideoFrame::MapMode mapMode = QVideoFrame::NotMapped;
     QVideoFrameFormat format;
     std::unique_ptr<QAbstractVideoBuffer> buffer;
     int mappedCount = 0;
     QMutex mapMutex;
     QString subtitleText;
     QtVideo::Rotation rotation = QtVideo::Rotation::None;
-    bool mirrored = false;
     QImage image;
     QMutex imageMutex;
 
